import java.io.*;
import java.net.*;
import java.util.*;

public class ClientSimplifie {
    BufferedReader lecture;  // pour le flot d'entrée venant du serveur
    PrintWriter ecriture;  // pour le flot de sortie vers le serveur
    Socket sock; // le socket client

    public ClientSimplifie() {
        // établie une connexion au serveur par un appel
        // à connexionServeur()
        attributesInit();
        try {
            connexionServeur("localhost", 5000);
        }
        catch (IOException e) {
            System.err.println("IOException: " + e);
            e.printStackTrace();
            closeRWIO();
        }
    }

    public ClientSimplifie(String adresseIPServeur, int portServeur) {
        // établie une connexion au serveur par un appel
        // à connexionServeur()
        attributesInit();
        try {
            connexionServeur(adresseIPServeur, portServeur);
        }
        catch (IOException e) {
            System.err.println("IOException: " + e);
            e.printStackTrace();
            closeRWIO();
        }
    }

    private void connexionServeur(String adresseIPServeur, int portServeur) throws IOException {
        // créer un objet socket lié au socket serveur et l'affecte à sock
        // puis établie les chaînages de flot nécessaires
        // pour l'envoi et la reception de messages
        sock = new Socket(adresseIPServeur, portServeur);

        OutputStream OStream = sock.getOutputStream();
        ecriture = new PrintWriter(OStream);

        InputStream IStream = sock.getInputStream();
        InputStreamReader IMesg = new InputStreamReader(IStream);
        lecture = new BufferedReader(IMesg);
    }

    private void attributesInit() {
        sock = null;
        lecture = null;
        ecriture  = null;
    }

    /**
     * Send a message on the opened client socket
     * @param msg a string containing the message to send
     */
    public void sendMsg(String msg) {
        ecriture.println(msg);
        ecriture.flush();
    }

    /**
     * Receive a message sent on the opened client socket
     * @return a string containing the received message
     */
    public String receiveMsg() throws IOException {
        String line = new String();
        //FIXME?: read only the line before the ending newline
        line = lecture.readLine();
        return line;
    }

    /**
     * Close all opened I/O streams attached to this object instance
     */
    public void closeRWIO() {
        try {
            if (sock != null)
                sock.close();
            if (lecture != null)
                lecture.close();
            if (ecriture != null)
                ecriture.close();
        }
        catch (IOException e) {
            System.err.println("IOException: " + e);
            e.printStackTrace();
        }
    }

} // fin classe ClientSimplifie
